@@ -5,20 +5,6 @@ import pandas as pd
 
 
 def filter_nones_from_dict(query_parameters: Dict[str, Optional[Any]]) -> Dict[str, Any]:
-    """
-    This function takes a list of parameters as a dict, and returns a dict containing only non null parameters
-
-    Examples:
-        >>> filter_nones_from_dict({"key1": None, "key2": "some value"})
-        {"key2": "some value"}
-
-    Args:
-        query_parameters (dict): query parameters in the form of a dict with `None` values
-
-    Returns:
-        dict: a dict with None values filtered
-
-    """
     return {k: v for k, v in query_parameters.items() if v}
 
 
@@ -37,22 +23,20 @@ def pb_timeseries_to_pandas(data):
         return pd.DataFrame()
 
     first_group = data[0]
-    rows = first_group.rows
     first_row = first_group.rows[0]
 
     dict_list = []
     for g in data:
-        for r in rows:
+        for r in g.rows:
             d = {}
             if g.group != "" and g.group != "default":
                 d["group"] = g.group
             for attr in first_row._meta.fields:
                 d[attr] = getattr(r, attr)
-
             dict_list.append(d)
 
     df = pd.DataFrame(dict_list)
-    df.convert_dtypes()
+    df = df.convert_dtypes()
 
     return df
 
@@ -72,4 +56,5 @@ def pb_list_to_pandas(data):
     first = data[0]
 
     df = pd.DataFrame([[getattr(i, attr) for attr in first._meta.fields] for i in data], columns=first._meta.fields)
+    df = df.convert_dtypes()
     return df
