@@ -1,5 +1,5 @@
 from oceanbolt.sdk.client import APIClient
-from oceanbolt.sdk.data import Ports, Countries, Commodities, Segments, Regions, Zones
+from oceanbolt.sdk.data import Ports, Countries, Commodities, Segments, Regions, Zones, Search
 from oceanbolt.sdk.data import TradeFlows, TradeFlowTimeseries
 from oceanbolt.sdk.data import PortCalls, PortCallTimeseries
 from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries, ChineseWatersTimeseries, FleetStatusTimeseries, FleetGrowthTimeseries, ZoneChangesTimeseries
@@ -40,8 +40,17 @@ def test_regions():
     assert len(df) > 0
 
 
-# Data endpoints
+def test_search_polygons():
+    df = Search(__client__).search_polygons("tokyo")
+    assert len(df) > 0
 
+
+def test_search_vessels():
+    df = Search(__client__).search_vessels("tenacity")
+    assert len(df) > 0
+
+
+# Data endpoints
 def test_congestion_vessels():
     df = CongestionVessels(__client__).get(country_code=["cn"], start_date="2021-01-01")
     assert len(df) > 0
